<?php

namespace Drupal\Tests\spamspan\FunctionalJavascript;

/**
 * Tests the spamspan javascript functionalities.
 *
 * @group spamspan
 */
class SpamSpanComplexHtmlMailToTest extends SpamSpanJsTestBase {

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringWithClass() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com" class="test">Test</a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a.spamspan.test');
    $session->elementAttributeContains('css', 'a.spamspan.test', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan.test', 'Test');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringWithId() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com" id="test-id">Test</a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a#test-id.spamspan');
    $session->elementAttributeContains('css', 'a#test-id.spamspan', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a#test-id.spamspan', 'Test');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringWithIdAndClass() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com" id="test-id" class="test">Test</a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a#test-id.spamspan.test');
    $session->elementAttributeContains('css', 'a#test-id.spamspan.test', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a#test-id.spamspan.test', 'Test');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringWithChildSpan() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com"><span>Test</span></a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a.spamspan > span');
    $session->elementAttributeContains('css', 'a.spamspan', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan > span', 'Test');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringChildSpanWithClass() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com"><span class="label">Label</span></a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a.spamspan > span.label');
    $session->elementAttributeContains('css', 'a.spamspan', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan > span.label', 'Label');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringMultipleChildSpansWithClass() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com"><span class="label">Label</span> <span class="value">Value</span></a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a.spamspan > span.label');
    $session->elementExists('css', 'a.spamspan > span.value');
    $session->elementAttributeContains('css', 'a.spamspan', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan > span.label', 'Label');
    $session->elementTextEquals('css', 'a.spamspan > span.value', 'Value');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringIdChildSpanWithClass() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com" id="test-id"><span class="label">Label</span></a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a#test-id.spamspan > span.label');
    $session->elementAttributeContains('css', 'a#test-id.spamspan', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan > span.label', 'Label');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringIdAndClassChildSpanWithClass() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com" id="test-id" class="test"><span class="label">Label</span></a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a#test-id.spamspan.test > span.label');
    $session->elementAttributeContains('css', 'a#test-id.spamspan.test', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan.test > span.label', 'Label');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringIdAndClassMutlipleChildSpanWithClasses() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:example@email.com" id="test-id" class="test"><span class="label">Label</span> <span class="value">Value</span></a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementExists('css', 'a#test-id.spamspan.test > span.label');
    $session->elementExists('css', 'a#test-id.spamspan.test > span.value');
    $session->elementAttributeContains('css', 'a#test-id.spamspan.test', 'href', 'mailto:example@email.com');
    $session->elementTextEquals('css', 'a.spamspan.test > span.label', 'Label');
    $session->elementTextEquals('css', 'a.spamspan.test > span.value', 'Value');
  }

  /**
   * Tests mail unobscuring.
   */
  public function testMailUnobscuringMultipleHtmlMailMarkup() {
    $session = $this->assertSession();
    // Create a node:
    $node = $this->createNode([
      'type' => 'article',
      'title' => 'test123',
      'body' => [
        'value' => '<a href="mailto:first@email.com" id="test-id-first" class="test">first@email.com</a><a href="mailto:second@email.com" id="test-id-second" class="test">second@email.com</a><a href="mailto:third@email.com" id="test-id-third" class="test">third@email.com</a><a href="mailto:fourth@email.com" id="test-id-fourth" class="test">fourth@email.com</a>',
        'format' => 'spamspan_filter',
      ],
    ]);
    $node->save();

    // Go to the node, and see if the mail link is displayed correctly:
    $this->drupalGet('/node/' . $node->id());
    $session->pageTextContains('test123');
    $session->elementAttributeContains('css', 'a#test-id-first.spamspan.test', 'href', 'mailto:first@email.com');
    $session->elementAttributeContains('css', 'a#test-id-second.spamspan.test', 'href', 'mailto:second@email.com');
    $session->elementAttributeContains('css', 'a#test-id-third.spamspan.test', 'href', 'mailto:third@email.com');
    $session->elementAttributeContains('css', 'a#test-id-fourth.spamspan.test', 'href', 'mailto:fourth@email.com');
    $session->elementTextEquals('css', 'a#test-id-first.spamspan.test', 'first@email.com');
    $session->elementTextEquals('css', 'a#test-id-second.spamspan.test', 'second@email.com');
    $session->elementTextEquals('css', 'a#test-id-third.spamspan.test', 'third@email.com');
    $session->elementTextEquals('css', 'a#test-id-fourth.spamspan.test', 'fourth@email.com');
  }

}
